@@ -10,7 +10,8 @@
 #include <KLocalizedString>
 #include <KAuthorized>
 #include <KMessageBox>
-#include "downloaddialog.h"
+#include "qtquickdialogwrapper.h"
+#include "entry_p.h"
 #include "ui/widgetquestionlistener.h"
 
 #include <QPointer>
@@ -21,6 +22,7 @@ class ButtonPrivate
 {
 public:
     QString configFile;
+    QPointer<QtQuickDialogWrapper> dialog;
 };
 
 Button::Button(const QString &text,
@@ -80,13 +82,15 @@ void Button::showDialog()
     }
     Q_EMIT aboutToShowDialog();
 
-    QPointer<DownloadDialog> dialog = new DownloadDialog(d->configFile, this);
-    dialog->exec();
-
-    if (dialog)
-        Q_EMIT dialogFinished(dialog->changedEntries());
-
-    delete dialog;
+    if (!d->dialog) {
+       d->dialog = new QtQuickDialogWrapper(d->configFile, this);
+    }
+    const auto changedInternalEntries = d->dialog->exec();
+    QList<KNS3::Entry> changedEntries;
+    for (const KNSCore::EntryInternal &e : changedInternalEntries) {
+        changedEntries << EntryPrivate::fromInternal(&e);
+    }
+    Q_EMIT dialogFinished(changedEntries);
 }
 
 }
