@@ -53,7 +53,7 @@ private Q_SLOTS:
 
 private:
     EntryInternal m_entry;
-    EntryInternal::PreviewType m_previewType;
+    const EntryInternal::PreviewType m_previewType;
     QByteArray m_buffer;
     HTTPJob *m_job = nullptr;
 };
