@@ -48,32 +48,38 @@ Installation::Installation(QObject *parent)
     , customName(false)
     , acceptHtml(false)
 {
-    // TODO KF6 Make this a real property, when we can refactor this and add a proper dptr
+    // TODO KF6 Make these real properties, when we can refactor this and add a proper dptr
     setProperty("kpackageType", QLatin1String(""));
+    setProperty("uncompressSetting", UncompressionOptions::NeverUncompress);
 }
 
 bool Installation::readConfig(const KConfigGroup &group)
 {
     // FIXME: add support for several categories later on
     // FIXME: read out only when actually installing as a performance improvement?
-    QString uncompresssetting = group.readEntry("Uncompress", QStringLiteral("never"));
+    uncompression = group.readEntry("Uncompress", QStringLiteral("never"));
+    UncompressionOptions opt;
     // support old value of true as equivalent of always
-    if (uncompresssetting == QLatin1String("subdir")) {
-        uncompresssetting = QStringLiteral("subdir");
+    if (uncompression == QLatin1String("true")) {
+        uncompression = QStringLiteral("always");
     }
-    else if (uncompresssetting == QLatin1String("true")) {
-        uncompresssetting = QStringLiteral("always");
-    }
-    if (uncompresssetting != QLatin1String("always")
-        && uncompresssetting != QLatin1String("archive")
-        && uncompresssetting != QLatin1String("subdir-archive")
-        && uncompresssetting != QLatin1String("never")
-        && uncompresssetting != QLatin1String("subdir")
-        && uncompresssetting != QLatin1String("kpackage")) {
+    if (uncompression == QLatin1String("always")) {
+        opt = AlwaysUncompress;
+    } else if (uncompression == QLatin1String("archive")) {
+        opt = UncompressIfArchive;
+    } else if (uncompression == QLatin1String("subdir")) {
+        opt = UncompressIntoSubdir;
+    } else if (uncompression == QLatin1String("kpackage")) {
+        opt = UseKPackageUncompression;
+    } else if (uncompression == QLatin1String("subdir-archive")) {
+        opt = UncompressIntoSubdirIfArchive;
+    } else if (uncompression == QLatin1String("never")) {
+        opt =  NeverUncompress;
+    } else {
         qCCritical(KNEWSTUFFCORE) << "invalid Uncompress setting chosen, must be one of: subdir, always, archive, never, or kpackage";
         return false;
     }
-    uncompression = uncompresssetting;
+    setProperty("uncompressSetting", opt);
     setProperty("kpackageType", group.readEntry("KPackageType"));
     postInstallationCommand = group.readEntry("InstallationCommand");
     uninstallCommand = group.readEntry("UninstallCommand");
@@ -81,6 +87,7 @@ bool Installation::readConfig(const KConfigGroup &group)
     targetDirectory = group.readEntry("TargetDir");
     xdgTargetDirectory = group.readEntry("XdgTargetDir");
 
+#if KNEWSTUFFCORE_BUILD_DEPRECATED_SINCE(5, 77)
     // Provide some compatibility
     if (standardResourceDirectory == QLatin1String("wallpaper")) {
         xdgTargetDirectory = QStringLiteral("wallpapers");
@@ -93,7 +100,6 @@ bool Installation::readConfig(const KConfigGroup &group)
         uncompression = QStringLiteral("subdir");
     }
 
-    // TODO KF6 Remove this compatibility block
     // A touch of special treatment for the various old kpackage based knsrc files, so they work
     // with the new, internal stuff. The result unfortunately is that all entries marked as
     // installed in knewstuff no longer will be, but since it never worked right anyway... we'll
@@ -117,6 +123,7 @@ bool Installation::readConfig(const KConfigGroup &group)
         setProperty("kpackageType", uninstallCommand.mid(21, uninstallCommand.length() - 21 - 12));
         qCWarning(KNEWSTUFFCORE) << "Your configuration file uses an old version of the kpackage support, and should be converted. Please report this to the author of the software you are currently using. The package type, we assume, is" << property("kpackageType").toString();
     }
+#endif
 
     installPath = group.readEntry("InstallPath");
     absoluteInstallPath = group.readEntry("AbsoluteInstallPath");
@@ -181,10 +188,12 @@ bool Installation::readConfig(const KConfigGroup &group)
     return true;
 }
 
+#if KNEWSTUFFCORE_BUILD_DEPRECATED_SINCE(5, 71)
 bool Installation::isRemote() const
 {
     return false;
 }
+#endif
 
 void Installation::install(const EntryInternal& entry)
 {
@@ -272,7 +281,7 @@ void KNSCore::Installation::install(KNSCore::EntryInternal entry, const QString&
     QString targetPath = targetInstallationPath();
     QStringList installedFiles = installDownloadedFileAndUncompress(entry, downloadedFile, targetPath);
 
-    if (uncompression != QLatin1String("kpackage")) {
+    if (uncompressionSetting() != UseKPackageUncompression) {
         if (installedFiles.isEmpty()) {
             if (entry.status() == KNS3::Entry::Installing) {
                 entry.setStatus(KNS3::Entry::Downloadable);
@@ -393,9 +402,10 @@ QStringList Installation::installDownloadedFileAndUncompress(const KNSCore::Entr
     // Collect all files that were installed
     QStringList installedFiles;
     bool isarchive = true;
+    UncompressionOptions uncompressionOpt = uncompressionSetting();
 
     // respect the uncompress flag in the knsrc
-    if (uncompression == QLatin1String("kpackage")) {
+    if (uncompressionOpt == UseKPackageUncompression) {
         qCDebug(KNEWSTUFFCORE) << "Using KPackage for installation";
         KPackage::PackageStructure structure;
         KPackage::Package package(&structure);
@@ -504,7 +514,10 @@ QStringList Installation::installDownloadedFileAndUncompress(const KNSCore::Entr
             qCWarning(KNEWSTUFFCORE) << "No valid meta information (which suggests no valid KPackage) found in" << payloadfile;
         }
     } else {
-        if (uncompression == QLatin1String("always") || uncompression == QLatin1String("subdir-archive") || uncompression == QLatin1String("archive") || uncompression == QLatin1String("subdir")) {
+        if (uncompressionOpt == AlwaysUncompress
+            || uncompressionOpt == UncompressIntoSubdirIfArchive
+            || uncompressionOpt == UncompressIfArchive
+            || uncompressionOpt == UncompressIntoSubdir) {
             // this is weird but a decompression is not a single name, so take the path instead
             QMimeDatabase db;
             QMimeType mimeType = db.mimeTypeForFile(payloadfile);
@@ -526,7 +539,7 @@ QStringList Installation::installDownloadedFileAndUncompress(const KNSCore::Entr
                 archive.reset(new KTar(payloadfile));
             } else {
                 qCCritical(KNEWSTUFFCORE) << "Could not determine type of archive file '" << payloadfile << "'";
-                if (uncompression == QLatin1String("always")) {
+                if (uncompressionOpt == AlwaysUncompress) {
                     Q_EMIT signalInstallationError(i18n("Could not determine the type of archive of the downloaded file %1", payloadfile));
                     return QStringList();
                 }
@@ -537,7 +550,7 @@ QStringList Installation::installDownloadedFileAndUncompress(const KNSCore::Entr
                 bool success = archive->open(QIODevice::ReadOnly);
                 if (!success) {
                     qCCritical(KNEWSTUFFCORE) << "Cannot open archive file '" << payloadfile << "'";
-                    if (uncompression == QLatin1String("always")) {
+                    if (uncompressionOpt == AlwaysUncompress) {
                         Q_EMIT signalInstallationError(i18n("Failed to open the archive file %1. The reported error was: %2", payloadfile, archive->errorString()));
                         return QStringList();
                     }
@@ -550,7 +563,7 @@ QStringList Installation::installDownloadedFileAndUncompress(const KNSCore::Entr
                     //if there is more than an item in the file, and we are requested to do so
                     //put contents in a subdirectory with the same name as the file
                     QString installpath;
-                    const bool isSubdir = (uncompression == QLatin1String("subdir-archive") || uncompression == QLatin1String("subdir")) && dir->entries().count() > 1;
+                    const bool isSubdir = (uncompressionOpt == UncompressIntoSubdir || uncompressionOpt == UncompressIntoSubdirIfArchive) && dir->entries().count() > 1;
                     if (isSubdir) {
                         installpath = installdir + QLatin1Char('/') + QFileInfo(archive->fileName()).baseName();
                     } else {
@@ -578,9 +591,9 @@ QStringList Installation::installDownloadedFileAndUncompress(const KNSCore::Entr
 
         //some wallpapers are compressed, some aren't
         if ((!isarchive && standardResourceDirectory == QLatin1String("wallpaper")) ||
-            (uncompression == QLatin1String("never")
-            || (uncompression == QLatin1String("archive") && !isarchive)
-            || (uncompression == QLatin1String("subdir-archive") && !isarchive))
+            (uncompressionOpt == NeverUncompress
+            || (uncompressionOpt == UncompressIfArchive && !isarchive)
+            || (uncompressionOpt == UncompressIntoSubdirIfArchive && !isarchive))
             ) {
             // no decompress but move to target
 
@@ -593,24 +606,14 @@ QStringList Installation::installDownloadedFileAndUncompress(const KNSCore::Entr
             if (customName) {
                 // Otherwise name can be interpreted as path
                 installfile = entry.name().remove(QLatin1Char('/'));
-                installfile += QLatin1Char('-') + entry.version();
+                if (!entry.version().isEmpty()) {
+                    installfile += QLatin1Char('-') + entry.version();
+                }
                 if (!ext.isEmpty()) {
                     installfile += QLatin1Char('.') + ext;
                 }
             } else {
-                // TODO HACK This is a hack, the correct way of fixing it would be doing the KIO::get
-                // and using the http headers if they exist to get the file name, but as discussed in
-                // Randa this is not going to happen anytime soon (if ever) so go with the hack
-                if (source.url().startsWith(QLatin1String("http://newstuff.kde.org/cgi-bin/hotstuff-access?file="))) {
-                    installfile = QUrlQuery(source).queryItemValue(QStringLiteral("file"));
-                    int lastSlash = installfile.lastIndexOf(QLatin1Char('/'));
-                    if (lastSlash >= 0) {
-                        installfile = installfile.mid(lastSlash);
-                    }
-                }
-                if (installfile.isEmpty()) {
-                    installfile = source.fileName();
-                }
+                installfile = source.fileName();
             }
             QString installpath = QDir(installdir).filePath(installfile);
 
@@ -719,7 +722,7 @@ void Installation::uninstall(EntryInternal entry)
         Q_EMIT signalEntryChanged(newEntry);
     };
 
-    if (uncompression == QLatin1String("kpackage")) {
+    if (uncompressionSetting() == UseKPackageUncompression) {
         const auto lst = entry.installedFiles();
         if (lst.length() == 1) {
             const QString installedFile{lst.first()};
@@ -879,25 +882,16 @@ void Installation::uninstall(EntryInternal entry)
 
 Installation::UncompressionOptions Installation::uncompressionSetting() const
 {
-    if (uncompression == QLatin1String("always")) {
-        return AlwaysUncompress;
-    } else if (uncompression == QLatin1String("archive")) {
-        return UncompressIfArchive;
-    } else if (uncompression == QLatin1String("subdir")) {
-        return UncompressIntoSubdir;
-    } else if (uncompression == QLatin1String("kpackage")) {
-        return UseKPackageUncompression;
-    } else if (uncompression == QLatin1String("subdir-archive")) {
-        return UncompressIntoSubdirIfArchive;
-    }
-    return NeverUncompress;
+    return property("uncompressSetting").value<UncompressionOptions>();
 }
 
+#if KNEWSTUFFCORE_BUILD_DEPRECATED_SINCE(5, 31)
 void Installation::slotInstallationVerification(int result)
 {
     Q_UNUSED(result)
     // Deprecated, was wired up to defunct Security class.
 }
+#endif
 
 QStringList Installation::archiveEntries(const QString &path, const KArchiveDirectory *dir)
 {
