@@ -1,18 +1,7 @@
 /*
-    Copyright (C) 2016 Dan Leinir Turthra Jensen <admin@leinir.dk>
+    SPDX-FileCopyrightText: 2016 Dan Leinir Turthra Jensen <admin@leinir.dk>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef FILECOPYJOB_H
@@ -32,9 +21,9 @@ public:
 
     explicit FileCopyJob(const QUrl& source, const QUrl& destination, int permissions=-1, JobFlags flags = DefaultFlags, QObject* parent = nullptr);
     explicit FileCopyJob(QObject* parent = nullptr);
-    virtual ~FileCopyJob();
+    ~FileCopyJob() override;
 
-    Q_SCRIPTABLE void start() Q_DECL_OVERRIDE;
+    Q_SCRIPTABLE void start() override;
 
     QUrl destUrl() const;
     QUrl srcUrl() const;
