@@ -1,24 +1,13 @@
 /*
     knewstuff3/ui/downloaddialog.cpp.
-    Copyright (C) 2005 by Enrico Ros <eros.kde@email.it>
-    Copyright (C) 2005 - 2007 Josef Spillner <spillner@kde.org>
-    Copyright (C) 2007 Dirk Mueller <mueller@kde.org>
-    Copyright (C) 2007-2009 Jeremy Whiting <jpwhiting@kde.org>
-    Copyright (C) 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
-    Copyright (C) 2010 Reza Fatahilah Shah <rshah0385@kireihana.com>
+    SPDX-FileCopyrightText: 2005 Enrico Ros <eros.kde@email.it>
+    SPDX-FileCopyrightText: 2005-2007 Josef Spillner <spillner@kde.org>
+    SPDX-FileCopyrightText: 2007 Dirk Mueller <mueller@kde.org>
+    SPDX-FileCopyrightText: 2007-2009 Jeremy Whiting <jpwhiting@kde.org>
+    SPDX-FileCopyrightText: 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2010 Reza Fatahilah Shah <rshah0385@kireihana.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "downloadwidget.h"
@@ -26,11 +15,10 @@
 
 #include <QTimer>
 #include <QScrollBar>
-#include <QKeyEvent>
 #include <QCoreApplication>
 
-#include <kmessagebox.h>
-#include <klocalizedstring.h>
+#include <KMessageBox>
+#include <KLocalizedString>
 #include <knewstuff_debug.h>
 
 #include "core/itemsmodel.h"
@@ -88,7 +76,7 @@ Entry::List DownloadWidget::changedEntries()
 {
     Entry::List entries;
     entries.reserve(d->changedEntries.count());
-    foreach (const KNSCore::EntryInternal &e, d->changedEntries) {
+    for (const KNSCore::EntryInternal &e : qAsConst(d->changedEntries)) {
         entries.append(EntryPrivate::fromInternal(&e));
     }
     return entries;
@@ -97,7 +85,7 @@ Entry::List DownloadWidget::changedEntries()
 Entry::List DownloadWidget::installedEntries()
 {
     Entry::List entries;
-    foreach (const KNSCore::EntryInternal &e, d->changedEntries) {
+    for (const KNSCore::EntryInternal &e : qAsConst(d->changedEntries)) {
         if (e.status() == Entry::Installed) {
             entries.append(EntryPrivate::fromInternal(&e));
         }
@@ -201,10 +189,12 @@ void DownloadWidgetPrivate::slotInfo(QString provider, QString server, QString v
                              i18n("Provider information"));
 }
 
-void DownloadWidgetPrivate::slotEntryChanged(const KNSCore::EntryInternal &entry)
+void DownloadWidgetPrivate::slotEntryEvent(const KNSCore::EntryInternal &entry, KNSCore::EntryInternal::EntryEvent event)
 {
-    changedEntries.insert(entry);
-    model->slotEntryChanged(entry);
+    if (event == KNSCore::EntryInternal::StatusChangedEvent) {
+        changedEntries.insert(entry);
+        model->slotEntryChanged(entry);
+    }
 }
 
 void DownloadWidgetPrivate::slotPayloadFailed(const KNSCore::EntryInternal &entry)
@@ -242,16 +232,21 @@ void DownloadWidgetPrivate::init(const QString &configFile)
 
     q->connect(engine, &KNSCore::Engine::signalMessage, this, &DownloadWidgetPrivate::slotShowMessage);
 
-    q->connect(engine, &KNSCore::Engine::signalBusy, ui.progressIndicator, &ProgressIndicator::busy);
     q->connect(engine, &KNSCore::Engine::signalErrorCode, ui.progressIndicator, &ProgressIndicator::error);
-    q->connect(engine, &KNSCore::Engine::signalIdle, ui.progressIndicator, &ProgressIndicator::idle);
+    q->connect(engine, &KNSCore::Engine::busyStateChanged, this ,[this]() {
+        if (!engine->busyState()) {
+            ui.progressIndicator->idle(QString());
+        } else {
+            ui.progressIndicator->busy(engine->busyMessage());
+        }
+    });
 
     q->connect(engine, &KNSCore::Engine::signalProvidersLoaded, this, &DownloadWidgetPrivate::slotProvidersLoaded);
     // Entries have been fetched and should be shown:
     q->connect(engine, &KNSCore::Engine::signalEntriesLoaded, this, &DownloadWidgetPrivate::slotEntriesLoaded);
 
     // An entry has changes - eg because it was installed
-    q->connect(engine, &KNSCore::Engine::signalEntryChanged, this, &DownloadWidgetPrivate::slotEntryChanged);
+    q->connect(engine, &KNSCore::Engine::signalEntryEvent, this, &DownloadWidgetPrivate::slotEntryEvent);
 
     q->connect(engine, &KNSCore::Engine::signalResetView, model, &KNSCore::ItemsModel::clearEntries);
     q->connect(engine, &KNSCore::Engine::signalEntryPreviewLoaded,
@@ -303,8 +298,8 @@ void DownloadWidgetPrivate::init(const QString &configFile)
                     }
                 }
             });
-    ui.detailsStack->widget(0)->layout()->setMargin(0);
-    ui.detailsStack->widget(1)->layout()->setMargin(0);
+    ui.detailsStack->widget(0)->layout()->setContentsMargins(0, 0, 0, 0);
+    ui.detailsStack->widget(1)->layout()->setContentsMargins(0, 0, 0, 0);
 
     q->connect(ui.m_categoryCombo, static_cast<void(KComboBox::*)(int)>(&KComboBox::activated),
                this, &DownloadWidgetPrivate::slotCategoryChanged);
