@@ -1,37 +1,24 @@
 /*
-    Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (c) 2003 - 2007 Josef Spillner <spillner@kde.org>
-    Copyright (c) 2009 Jeremy Whiting <jpwhiting@kde.org>
-    Copyright (C) 2009 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2002 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2003-2007 Josef Spillner <spillner@kde.org>
+    SPDX-FileCopyrightText: 2009 Jeremy Whiting <jpwhiting@kde.org>
+    SPDX-FileCopyrightText: 2009 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef KNEWSTUFF3_KNEWSTUFFENTRY_H
 #define KNEWSTUFF3_KNEWSTUFFENTRY_H
 
-#include <QtCore/QStringList>
-#include <QtCore/QSharedDataPointer>
+#include <QStringList>
+#include <QSharedDataPointer>
 #include <QLoggingCategory>
 
 #include "knewstuff_export.h"
-
-Q_DECLARE_LOGGING_CATEGORY(KNEWSTUFF)
-
+namespace KNSCore { class EntryInternal; }
 namespace KNS3
 {
-
+class EntryPrivate;
 /**
  * @short KNewStuff information about changed entries
  *
@@ -63,7 +50,7 @@ public:
         Updateable,
         Deleted,
         Installing,
-        Updating
+        Updating,
     };
 
     ~Entry();
@@ -121,12 +108,14 @@ public:
     * Retrieve the version string of the object.
     *
     * @return object version
+    *
+    * @sa installedVersion()
     */
     QString version() const;
 
     /**
      * Id of this Entry. It is guaranteed to be unique for one provider.
-     * Id and ProviderId together identifiy this entry.
+     * Id and ProviderId together identify this entry.
      * @return the id
      * @since 4.5
      */
@@ -139,13 +128,72 @@ public:
      */
     QString providerId() const;
 
+    /**
+     * @returns if available an url identifying the asset
+     * @since 5.23
+     */
+    QUrl url() const;
+
+    /**
+     * @returns a list of urls to small previews to be displayed as thumbnails
+     * @since 5.23
+     */
+    QList<QUrl> previewThumbnails() const;
+
+    /**
+     * @returns a list of full previews of the asset
+     * @since 5.23
+     */
+    QList<QUrl> previewImages() const;
+
+    /**
+     * @returns the advertised disk size of the asset
+     * @since 5.23
+     */
+    quint64 size() const;
+
+    /**
+     * @returns the number of comments in the asset
+     * @since 5.23
+     */
+    uint numberOfComments() const;
+
+    /**
+     * @returns the rating of the asset, between 0 and 100
+     * @since 5.23
+     */
+    uint rating() const;
+
+    /**
+     * @returns the asset's change log
+     * @since 5.23
+     */
+    QString changelog() const;
+
+    /**
+     * @returns a short one-line summary of the asset
+     * @since 5.23
+     */
+    QString shortSummary() const;
+
+    /**
+     * @returns the available version
+     *
+     * If the entry is not updateable, it will be the same as version.
+     *
+     * @sa version()
+     *
+     * @since 5.23
+     */
+    QString updateVersion() const;
+
 private:
     Entry();
 
-    class Private;
-    QExplicitlySharedDataPointer<Private> d;
+    QExplicitlySharedDataPointer<EntryPrivate> d;
 
-    friend class EntryInternal;
+    friend class KNSCore::EntryInternal;
+    friend class EntryPrivate;
 };
 
 }
