@@ -20,7 +20,7 @@
 
 #include <KLocalizedString>
 
-#define _ QLatin1String
+#define _ QStringLiteral
 
 /**
  * Makes sure that if the same inputId is given more than once
@@ -160,7 +160,7 @@ public:
         // http://stackoverflow.com/questions/14131127/qbytearray-to-qstring
         // QJsonDocument uses UTF-8 => we use 106=UTF-8
         //return QTextCodec::codecForMib(106)->toUnicode(jByteArray);
-        return _(jByteArray); // accidentally the ctor of QString takes an UTF-8 byte array
+        return QString::fromUtf8(jByteArray); // accidentally the ctor of QString takes an UTF-8 byte array
     }
 
     void deserialize(const QString& text)
