@@ -1,18 +1,7 @@
 /*
-    Copyright 2015 by Gregor Mi <codestruct@posteo.org>
+    SPDX-FileCopyrightText: 2015 Gregor Mi <codestruct@posteo.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "kmoretoolsconfigdialog_p.h"
@@ -21,7 +10,6 @@
 
 #include <QDebug>
 #include <QStandardItemModel>
-#include <QMessageBox>
 
 #include <KLocalizedString>
 
@@ -121,7 +109,7 @@ public:
         QListWidgetItem* mainSelItem = nullptr;
         QListWidgetItem* moreSelItem = nullptr;
 
-        for (auto item : qAsConst(currentStructure.list)) {
+        for (const auto &item : qAsConst(currentStructure.list)) {
             QIcon icon = item.icon;
             if (icon.isNull()) {
                 QPixmap pix(16, 16); // TODO: should same size as other icons in the listview
@@ -133,15 +121,12 @@ public:
                 auto listItem = new QListWidgetItem(icon, KmtMenuItemDto::removeMenuAmpersand(item.text) /*+ " - " + item.id*/);
                 listItem->setData(Qt::UserRole, item.id);
                 if (item.menuSection == KMoreTools::MenuSection_Main) {
-                    //qDebug() << item.text << item.icon << item.icon.isNull() << item.icon.availableSizes();
-                    //itemModel->appendRow(new QStandardItem(icon, item.text /*+ " - " + item.id*/));
                     configUi->listMainSection->addItem(listItem);
                     if (item.id == idToSelect) {
                         mainSelItem = listItem;
                     }
                 } else if (item.menuSection == KMoreTools::MenuSection_More) {
                     configUi->listMoreSection->addItem(listItem);
-                    //configUi->listMoreSection->addItem("test"); // DND copies item instead of moving it
                     if (item.id == idToSelect) {
                         moreSelItem = listItem;
                     }
@@ -207,15 +192,6 @@ KMoreToolsConfigDialog::KMoreToolsConfigDialog(const KmtMenuStructureDto& defaul
         d->configUi->buttonNotInstalledTools->setMenu(menu);
     }
 
-    //auto itemModel = new QStandardItemModel();
-    //configUi->listMainSection->setModel(itemModel);
-    //configUi->listMainSection->setDragDropMode(QAbstractItemView::DragOnly);
-    //configUi->listMainSection->setDragEnabled(true); // QWARN  : KMoreToolsTest::testConfigDialog() Trying to construct an instance of an invalid type, type id: 872443648
-    //configUi->listMainSection->setAcceptDrops(true); // ...and crash when doing to much DND. Why? ...
-    //configUi->listMainSection->setDropIndicatorShown(true);
-    //configUi->listMoreSection->setDragEnabled(true); // crashes on DND. Why?
-    //configUi->listMoreSection->setAcceptDrops(true);
-
     //
     // connect signals
     //
