@@ -1,29 +1,19 @@
 /*
     This file is part of KNewStuff2.
-    Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2002 Cornelius Schumacher <schumacher@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "knewstuffaction.h"
 
 #include <QAction>
-#include <klocalizedstring.h>
-#include <kactioncollection.h>
+#include <KLocalizedString>
+#include <KActionCollection>
 
 using namespace KNS3;
 
+#if KNEWSTUFF_BUILD_DEPRECATED_SINCE(5, 78)
 QAction *KNS3::standardAction(const QString &what,
                               const QObject *receiver,
                               const char *slot, KActionCollection *parent,
@@ -36,7 +26,9 @@ QAction *KNS3::standardAction(const QString &what,
 
     return action;
 }
+#endif
 
+#if KNEWSTUFF_BUILD_DEPRECATED_SINCE(5, 78)
 QAction *KNS3::standardActionUpload(const QString &what,
                                     const QObject *receiver,
                                     const char *slot, KActionCollection *parent,
@@ -44,9 +36,9 @@ QAction *KNS3::standardActionUpload(const QString &what,
 {
     QAction *action = new QAction(what, parent);
     parent->addAction(QLatin1String(name), action);
-    // FIXME: Get a specific upload icon!
     action->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
     QObject::connect(action, SIGNAL(triggered(bool)), receiver, slot);
 
     return action;
 }
+#endif
