@@ -10,7 +10,6 @@
 #include <KLocalizedString>
 
 #include "categoriesmodel.h"
-#include "entrywrapper.h"
 #include "quickquestionlistener.h"
 
 #include "engine.h"
@@ -81,59 +80,67 @@ void Engine::setConfigFile(const QString &newFile)
 {
     if (d->configFile != newFile) {
         d->isLoading = true;
-        emit isLoadingChanged();
+        Q_EMIT isLoadingChanged();
         d->configFile = newFile;
-        emit configFileChanged();
+        Q_EMIT configFileChanged();
 
         if (allowedByKiosk()) {
             if (!d->engine) {
                 d->engine = new KNSCore::Engine(this);
                 connect(d->engine, &KNSCore::Engine::signalProvidersLoaded, this, [=](){
                     d->isLoading = false;
-                    emit isLoadingChanged();
+                    Q_EMIT isLoadingChanged();
                 });
                 connect(d->engine, &KNSCore::Engine::signalMessage, this, &Engine::message);
-                connect(d->engine, &KNSCore::Engine::signalIdle, this, &Engine::idleMessage);
-                connect(d->engine, &KNSCore::Engine::signalBusy, this, &Engine::busyMessage);
-                connect(d->engine, &KNSCore::Engine::signalError, this, &Engine::errorMessage);
+                connect(d->engine, &KNSCore::Engine::busyStateChanged, this, [this]() {
+                    if (!d->engine->busyState()) {
+                        idleMessage(QString());
+                    } else {
+                        busyMessage(d->engine->busyMessage());
+                    }
+                });
                 connect(d->engine, &KNSCore::Engine::signalErrorCode, this, [=](const KNSCore::ErrorCode &errorCode, const QString &message, const QVariant &/*metadata*/) {
                     if (errorCode == KNSCore::ProviderError) {
                         // This means loading the providers file failed entirely and we cannot complete the
                         // initialisation. It also means the engine is done loading, but that nothing will
                         // work, and we need to inform the user of this.
                         d->isLoading = false;
-                        emit isLoadingChanged();
+                        Q_EMIT isLoadingChanged();
                     }
-                    emit errorMessage(message);
+                    Q_EMIT errorMessage(message);
                 });
-                connect(d->engine, &KNSCore::Engine::signalEntryChanged, this, [this](const KNSCore::EntryInternal &entry){
-                    if (d->changedEntries.contains(entry) ) {
-                        d->changedEntries.removeAll(entry);
-                    }
-                    d->changedEntries << entry;
-                    emit changedEntriesChanged();
-                });
-                emit engineChanged();
+                connect(d->engine, &KNSCore::Engine::signalEntryEvent,
+                        this, [this](const KNSCore::EntryInternal &entry, KNSCore::EntryInternal::EntryEvent event) {
+                            if (event != KNSCore::EntryInternal::StatusChangedEvent) {
+                                return;
+                            }
+                            if (d->changedEntries.contains(entry)) {
+                                d->changedEntries.removeAll(entry);
+                            }
+                            d->changedEntries << entry;
+                            Q_EMIT changedEntriesChanged();
+                        });
+                Q_EMIT engineChanged();
                 KNewStuffQuick::QuickQuestionListener::instance();
                 d->categoriesModel = new CategoriesModel(this);
-                emit categoriesChanged();
+                Q_EMIT categoriesChanged();
                 // And finally, let's just make sure we don't miss out the various things here getting changed
                 // In other words, when we're asked to reset the view, actually do that
                 connect(d->engine, &KNSCore::Engine::signalResetView, this, &Engine::categoriesFilterChanged);
                 connect(d->engine, &KNSCore::Engine::signalResetView, this, &Engine::filterChanged);
                 connect(d->engine, &KNSCore::Engine::signalResetView, this, &Engine::sortOrderChanged);
                 connect(d->engine, &KNSCore::Engine::signalResetView, this, &Engine::searchTermChanged);
-                emit categoriesFilterChanged();
-                emit filterChanged();
-                emit sortOrderChanged();
-                emit searchTermChanged();
+                Q_EMIT categoriesFilterChanged();
+                Q_EMIT filterChanged();
+                Q_EMIT sortOrderChanged();
+                Q_EMIT searchTermChanged();
             }
             d->engine->init(d->configFile);
-            emit engineInitialized();
+            Q_EMIT engineInitialized();
         } else {
             // This is not an error message in the proper sense, and the message is not intended to look like an error (as there is really
             // nothing the user can do to fix it, and we just tell them so they're not wondering what's wrong)
-            emit message(i18nc("An informational message which is shown to inform the user they are not authorized to use GetHotNewStuff functionality", "You are not authorized to Get Hot New Stuff. If you think this is in error, please contact the person in charge of your permissions."));
+            Q_EMIT message(i18nc("An informational message which is shown to inform the user they are not authorized to use GetHotNewStuff functionality", "You are not authorized to Get Hot New Stuff. If you think this is in error, please contact the person in charge of your permissions."));
         }
     }
 }
@@ -186,7 +193,7 @@ void Engine::setCategoriesFilter(const QStringList &newCategoriesFilter)
         filter.removeAll({});
         if (d->engine->categoriesFilter() != filter) {
             d->engine->setCategoriesFilter(filter);
-            emit categoriesFilterChanged();
+            Q_EMIT categoriesFilterChanged();
         }
     }
 }
@@ -210,7 +217,7 @@ void Engine::setFilter(int newFilter)
 {
     if (d->engine && d->engine->filter() != newFilter) {
         d->engine->setFilter(static_cast<KNSCore::Provider::Filter>(newFilter));
-        emit filterChanged();
+        Q_EMIT filterChanged();
     }
 }
 
@@ -226,7 +233,7 @@ void Engine::setSortOrder(int newSortOrder)
 {
     if (d->engine && d->engine->sortMode() != newSortOrder) {
         d->engine->setSortMode(static_cast<KNSCore::Provider::SortMode>(newSortOrder));
-        emit sortOrderChanged();
+        Q_EMIT sortOrderChanged();
     }
 }
 
@@ -242,7 +249,7 @@ void Engine::setSearchTerm(const QString &newSearchTerm)
 {
     if (d->engine && d->engine->searchTerm() != newSearchTerm) {
         d->engine->setSearchTerm(newSearchTerm);
-        emit searchTermChanged();
+        Q_EMIT searchTermChanged();
     }
 }
 
@@ -264,5 +271,5 @@ int Engine::changedEntriesCount() const
 void Engine::resetChangedEntries()
 {
     d->changedEntries.clear();
-    emit changedEntriesChanged();
+    Q_EMIT changedEntriesChanged();
 }
