@@ -1,18 +1,7 @@
 /*
-    Copyright (C) 2009 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2009 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef KNEWSTUFF3_ENTRYDETAILSDIALOG_P_H
@@ -46,6 +35,7 @@ public Q_SLOTS:
 private Q_SLOTS:
     void slotEntryPreviewLoaded(const KNSCore::EntryInternal &entry, KNSCore::EntryInternal::PreviewType type);
     void install();
+    void installAction(QAction *action);
     void uninstall();
 
     void ratingChanged(uint rating);
@@ -53,7 +43,6 @@ private Q_SLOTS:
     // more details loaded
     void entryChanged(const KNSCore::EntryInternal &entry);
     // installed/updateable etc
-    void entryStatusChanged(const KNSCore::EntryInternal &entry);
     void updateButtons();
 
     void preview1Selected();
@@ -64,13 +53,13 @@ private:
     void init();
     void previewSelected(int current);
 
-    KNSCore::Engine *m_engine;
-    Ui::DownloadWidget *ui;
+    KNSCore::Engine *const m_engine;
+    Ui::DownloadWidget *const ui;
     KNSCore::EntryInternal m_entry;
     QImage m_currentPreview;
-    QListWidgetItem *m_previewItem1;
-    QListWidgetItem *m_previewItem2;
-    QListWidgetItem *m_previewItem3;
+    QListWidgetItem *m_previewItem1 = nullptr;
+    QListWidgetItem *m_previewItem2 = nullptr;
+    QListWidgetItem *m_previewItem3 = nullptr;
 };
 
 }
