@@ -1,36 +1,24 @@
 /*
     This file is part of KNewStuff2.
-    Copyright (C) 2008 Jeremy Whiting <jpwhiting@kde.org>
-    Copyright (C) 2010 Reza Fatahilah Shah <rshah0385@kireihana.com>
-    Copyright (C) 2010 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2008 Jeremy Whiting <jpwhiting@kde.org>
+    SPDX-FileCopyrightText: 2010 Reza Fatahilah Shah <rshah0385@kireihana.com>
+    SPDX-FileCopyrightText: 2010 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "itemsviewdelegate_p.h"
 
 #include <QPainter>
-#include <QSortFilterProxyModel>
 #include <QApplication>
 #include <QToolButton>
 #include <QMenu>
 #include <QProcess>
 #include <knewstuff_debug.h>
 
-#include <kformat.h>
-#include <klocalizedstring.h>
-#include <kratingwidget.h>
+#include <KFormat>
+#include <KLocalizedString>
+#include <KRatingWidget>
 #include <KShell>
 
 #include "core/itemsmodel.h"
@@ -158,13 +146,14 @@ void ItemsViewDelegate::updateItemWidgets(const QList<QWidget *> widgets,
         installButton->setIcon(icon);
         installButton->setPopupMode(QToolButton::InstantPopup);
 
-        if (installable && entry.downloadLinkCount() > 1) {
+        // If there are multiple files we want to show a dropdown, but not if it is just an update
+        if (installable && entry.downloadLinkCount() > 1 && entry.status() != Entry::Updateable) {
             QMenu *installMenu = new QMenu(installButton);
             const auto lst = entry.downloadLinkInformationList();
             for (const KNSCore::EntryInternal::DownloadLinkInformation &info : lst) {
                 QString text = info.name;
                 if (!info.distributionType.trimmed().isEmpty()) {
-                    text += QStringLiteral(" (") + info.distributionType.trimmed() + QLatin1Char(')');
+                    text += QLatin1String(" (") + info.distributionType.trimmed() + QLatin1Char(')');
                 }
                 QAction *installAction = installMenu->addAction(m_iconInstall, text);
                 installAction->setData(QPoint(index.row(), info.id));
@@ -172,10 +161,23 @@ void ItemsViewDelegate::updateItemWidgets(const QList<QWidget *> widgets,
             installButton->setMenu(installMenu);
         } else if (entry.status() == Entry::Installed && m_engine->hasAdoptionCommand()) {
             QMenu* m = new QMenu(installButton);
-            m->addAction(i18n("Use"), m, [this, entry](){
-                QStringList args = KShell::splitArgs(m_engine->adoptionCommand(entry));
-                qCDebug(KNEWSTUFF) << "executing AdoptionCommand" << args;
-                QProcess::startDetached(args.takeFirst(), args);
+            // Add icon to use dropdown, see also BUG: 385858
+            QAction *action = m->addAction(QIcon::fromTheme(QStringLiteral("checkmark")), m_engine->useLabel());
+            connect(action, &QAction::triggered, m, [this, entry](bool) {
+                m_engine->adoptEntry(entry);
+            });
+            installButton->setPopupMode(QToolButton::MenuButtonPopup);
+            installButton->setMenu(m);
+        }
+        // Add uninstall option for updatable entries, BUG: 422047
+        if (entry.status() == Entry::Updateable) {
+            QMenu* m = installButton->menu();
+            if (!m) {
+                m = new QMenu(installButton);
+            }
+            QAction *action = m->addAction(m_iconDelete, i18n("Uninstall"));
+            connect(action, &QAction::triggered, m, [this, entry](bool){
+                m_engine->uninstall(entry);
             });
             installButton->setPopupMode(QToolButton::MenuButtonPopup);
             installButton->setMenu(m);
@@ -220,7 +222,7 @@ void ItemsViewDelegate::updateItemWidgets(const QList<QWidget *> widgets,
 
         QUrl link = qvariant_cast<QUrl>(entry.homepage());
         if (!link.isEmpty()) {
-            text += QStringLiteral("<p><a href=\"") + link.url() + QStringLiteral("\">") + entry.name() + QStringLiteral("</a></p>\n");
+            text += QLatin1String("<p><a href=\"") + link.url() + QLatin1String("\">") + entry.name() + QLatin1String("</a></p>\n");
         } else {
             text += entry.name();
         }
@@ -239,15 +241,15 @@ void ItemsViewDelegate::updateItemWidgets(const QList<QWidget *> widgets,
 
         if (!authorName.isEmpty()) {
             if (!authorPage.isEmpty()) {
-                text += QStringLiteral("<p>") + i18nc("Show the author of this item in a list", "By <i>%1</i>", QStringLiteral(" <a href=\"") + authorPage + QStringLiteral("\">") + authorName + QStringLiteral("</a>")) + QStringLiteral("</p>\n");
+                text += QLatin1String("<p>") + i18nc("Show the author of this item in a list", "By <i>%1</i>", QLatin1String(" <a href=\"") + authorPage + QLatin1String("\">") + authorName + QLatin1String("</a>")) + QLatin1String("</p>\n");
             } else if (!email.isEmpty()) {
-                text += QStringLiteral("<p>") + i18nc("Show the author of this item in a list", "By <i>%1</i>", authorName) + QStringLiteral(" <a href=\"mailto:") + email + QStringLiteral("\">") + email + QStringLiteral("</a></p>\n");
+                text += QLatin1String("<p>") + i18nc("Show the author of this item in a list", "By <i>%1</i>", authorName) + QLatin1String(" <a href=\"mailto:") + email + QLatin1String("\">") + email + QLatin1String("</a></p>\n");
             } else {
-                text += QStringLiteral("<p>") + i18nc("Show the author of this item in a list", "By <i>%1</i>", authorName) + QStringLiteral("</p>\n");
+                text += QLatin1String("<p>") + i18nc("Show the author of this item in a list", "By <i>%1</i>", authorName) + QLatin1String("</p>\n");
             }
         }
 
-        QString summary = QStringLiteral("<p>") + option.fontMetrics.elidedText(entry.summary(),
+        QString summary = QLatin1String("<p>") + option.fontMetrics.elidedText(entry.summary(),
                           Qt::ElideRight, infoLabel->width() * 3) + QStringLiteral("</p>\n");
         text += summary;
 
@@ -263,7 +265,7 @@ void ItemsViewDelegate::updateItemWidgets(const QList<QWidget *> widgets,
             downloadString = i18np("1 download", "%1 downloads", downloads);
         }
         if (downloads > 0 || fans > 0) {
-            text += QStringLiteral("<p>") + downloadString;
+            text += QLatin1String("<p>") + downloadString;
             if (downloads > 0 && fans > 0) {
                 text += QLatin1String(", ");
             }
@@ -330,7 +332,11 @@ void ItemsViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &opt
                 painter->drawImage(point, image);
 
                 QPoint framePoint(point.x() - 5, point.y() - 5);
-                painter->drawPixmap(framePoint, m_frameImage.scaled(image.width() + 10, image.height() + 10));
+                if (m_frameImage.isNull()) {
+                    painter->drawPixmap(framePoint, m_frameImage);
+                } else {
+                    painter->drawPixmap(framePoint, m_frameImage.scaled(image.width() + 10, image.height() + 10));
+                }
             } else {
                 QRect rect(point, QSize(KNSCore::PreviewWidth, KNSCore::PreviewHeight));
                 painter->drawText(rect, Qt::AlignCenter | Qt::TextWordWrap, i18n("Loading Preview"));
